@@ -29,7 +29,7 @@ import inspect
 from enum import IntEnum, Enum
 from functools import wraps
 from collections import OrderedDict
-from typing import Iterable, BinaryIO, Union, List, Optional, Callable, Tuple, Any, ByteString
+from typing import Iterable, BinaryIO, Union, List, Optional, Callable, Tuple, Any, ByteString, no_type_check
 from argparse import (
     ArgumentParser,
     ArgumentError,
@@ -506,6 +506,9 @@ class Executable(type):
 
         nmspc.setdefault('__doc__', '')
 
+        try: nmspc['__init__'] = no_type_check(nmspc['__init__'])
+        except KeyError: pass
+
         for op in ('process', 'reverse'):
             if op in nmspc:
                 nmspc[op] = normalize(nmspc[op])
@@ -517,15 +520,24 @@ class Executable(type):
 
     def __init__(cls, name, bases, nmspc, abstract=False):
         super(Executable, cls).__init__(name, bases, nmspc)
-        parameters = inspect.signature(cls.__init__).parameters
-        cls.argspec = ArgumentSpecification()
+        cls._argspec_ = ArgumentSpecification()
 
-        if bases:
-            parent = bases[0]
-            for key, value in parent.argspec.items():
+        cls_init = cls.__init__
+        sig_init = inspect.signature(cls_init)
+        parameters = sig_init.parameters
+
+        for base in bases:
+            for key, value in base._argspec_.items():
                 if not value.guess and key in parameters:
-                    cls.argspec[key] = value.__copy__()
-            cls._infer_argspec(parameters, cls.argspec)
+                    cls._argspec_[key] = value.__copy__()
+            cls._infer_argspec(parameters, cls._argspec_)
+
+        if not abstract and any(p.kind == p.VAR_KEYWORD for p in parameters.values()):
+            @wraps(cls.__init__)
+            def init(self, *args, **kwargs): super(cls, self).__init__(*args, **kwargs)
+            init.__signature__ = sig_init.replace(parameters=tuple(
+                p for p in parameters.values() if p.kind != p.VAR_KEYWORD))
+            cls.__init__ = init
 
         if cls.__init__.__code__.co_code == (lambda: None).__code__.co_code:
             base = bases[0]
@@ -948,7 +960,11 @@ class Unit(metaclass=Executable, abstract=True):
         except StopIteration:
             return B''
 
-    def __call__(self, data: Optional[ByteString] = None) -> bytes:
+    def act(self, data: Union[Chunk, ByteString]) -> Union[ByteString, Chunk, None]:
+        op = self.reverse if self.args.reverse else self.process
+        return op(data)
+
+    def __call__(self, data: Union[ByteString, Chunk, None] = None) -> bytes:
         with io.BytesIO(data) if data else open(os.devnull, 'rb') as stdin:
             with io.BytesIO() as stdout:
                 return (stdin | self | stdout).getvalue()
@@ -1010,15 +1026,17 @@ class Unit(metaclass=Executable, abstract=True):
 
     @classmethod
     def _output(cls, *messages) -> None:
-        def transform(x):
-            try: x = x()
-            except TypeError: pass
-            if isinstance(x, str):
-                return x
-            if isinstance(x, (bytes, bytearray, memoryview)):
+        def transform(message):
+            if callable(message):
+                message = message()
+            if isinstance(message, str):
+                return message
+            if isbuffer(message):
                 import codecs
-                return codecs.decode(x, cls.codec, errors='backslashreplace')
-            return str(x)
+                return codecs.decode(message, cls.codec, errors='backslashreplace')
+            else:
+                import pprint
+                return pprint.pformat(message)
         message = ' '.join(transform(msg) for msg in messages)
         print(F'{cls.name}: {message}', file=sys.stderr)
 
@@ -1047,7 +1065,7 @@ class Unit(metaclass=Executable, abstract=True):
 
         groups = {None: argp}
 
-        for argument in reversed(cls.argspec.values()):
+        for argument in reversed(cls._argspec_.values()):
             gp = argument.group
             if gp not in groups:
                 groups[gp] = argp.add_mutually_exclusive_group()
@@ -1168,13 +1186,21 @@ class Unit(metaclass=Executable, abstract=True):
         manually. This is a convenience feature which reduces code bloat when many parameters have to be
         forwarded, see e.g. `refinery.units.pattern.carve.carve` for an example.
         """
-        args = inspect.signature(spc.__thisclass__.__init__).parameters
-        keep = list(skipfirst(args))
-        junk = [a for a in keywords if a not in keep]
-        for j in junk: del keywords[j]
-        for a in args.values():
+        my_own_args = iter(inspect.signature(spc.__thisclass__.__init__).parameters.values())
+        parent_args = inspect.signature(spc.__init__).parameters
+        keywords.pop(next(my_own_args).name, None)
+        for a in my_own_args:
             if a.kind is a.VAR_KEYWORD:
                 keywords.update(keywords.pop(a.name, {}))
+        junk = [a for a in keywords]
+        for a in parent_args.values():
+            if a.kind is a.VAR_KEYWORD:
+                junk = [j for j in junk if j.startswith('_')]
+                break
+            try: junk.remove(a.name)
+            except ValueError: pass
+        for j in junk:
+            del keywords[j]
         try:
             if spc.__init__.__func__ is Unit.__init__:
                 return spc.__init__(**keywords)
