@@ -32,21 +32,6 @@ class CipherUnit(Unit, metaclass=CipherExecutable, abstract=True):
     def __init__(self, key: arg(help='The encryption key.'), **keywords):
         super().__init__(key=key, **keywords)
 
-    @property
-    def key_size_chosen(self) -> int:
-        try:
-            return self.args.key_size
-        except AttributeError:
-            return self.maximum_key_size
-
-    @property
-    def maximum_key_size(self) -> int:
-        return max(self.key_sizes)
-
-    @property
-    def key(self) -> ByteString:
-        return self.args.key
-
     def decrypt(self, data: ByteString) -> ByteString:
         raise NotImplementedError
 
@@ -54,6 +39,8 @@ class CipherUnit(Unit, metaclass=CipherExecutable, abstract=True):
         raise NotImplementedError
 
     def process(self, data: ByteString) -> ByteString:
+        if len(self.args.key) not in self.key_sizes:
+            raise ValueError(F'the key has length {len(self.args.key)}')
         return self.decrypt(data)
 
     def reverse(self, data: ByteString) -> ByteString:
@@ -146,16 +133,16 @@ class StandardCipherExecutable(CipherExecutable):
     def __init__(cls, name, bases, nmspc, cipher=NotImplemented):
         super(StandardCipherExecutable, cls).__init__(
             name, bases, nmspc, abstract=cipher is NotImplemented)
-        cls.stdcipher = cipher
-        if cipher is not NotImplemented and cipher.block_size > 1 and 'mode' in cls.argspec:
+        cls._stdcipher_ = cipher
+        if cipher is not NotImplemented and cipher.block_size > 1 and 'mode' in cls._argspec_:
             modes = extract_options(cipher)
             if not modes:
                 raise RefineryCriticalException(
                     F'The cipher {cipher.name} is a block cipher module, '
                     F'but no cipher block mode constants were found.'
                 )
-            cls.modespec = OptionFactory(modes, ignorecase=True)
-            cls.argspec['mode'].merge_all(arg(
+            cls._bcmspec_ = OptionFactory(modes, ignorecase=True)
+            cls._argspec_['mode'].merge_all(arg(
                 dest='mode', type=str.upper, metavar='mode', choices=list(modes),
                 help='Choose cipher mode to be used. Possible values are: {}.'.format(', '.join(modes))
             ))
@@ -167,8 +154,8 @@ class StandardCipherUnit(CipherUnit, metaclass=StandardCipherExecutable):
         super().__init__(key, **keywords)
 
     def _get_cipher_instance(self, **optionals) -> Any:
-        self.log_info('encryption key:', self.key.hex())
-        return self.stdcipher.new(key=self.key, **optionals)
+        self.log_info(lambda: F'encryption key: {self.args.key.hex()}')
+        return self._stdcipher_.new(key=self.args.key, **optionals)
 
     def encrypt(self, data: bytes) -> bytes:
         return self._get_cipher_instance().encrypt(data)
@@ -180,7 +167,7 @@ class StandardCipherUnit(CipherUnit, metaclass=StandardCipherExecutable):
 class StandardBlockCipherUnit(BlockCipherUnitBase, StandardCipherUnit):
 
     def __init__(self, mode, key, iv=B'', padding=None):
-        super().__init__(key=key, iv=iv, padding=padding, mode=self.modespec(mode))
+        super().__init__(key=key, iv=iv, padding=padding, mode=self._bcmspec_(mode))
 
     def _get_cipher_instance(self, **optionals) -> Any:
         if not self.args.mode.name == 'ECB':
@@ -196,7 +183,7 @@ class StandardBlockCipherUnit(BlockCipherUnitBase, StandardCipherUnit):
             del optionals['IV']
             if self.iv:
                 self.log_info('ignoring IV for mode', self.args.mode)
-            return self.stdcipher.new(key=self.key, **optionals)
+            return self._stdcipher_.new(key=self.args.key, **optionals)
 
 
 class LatinStreamCipher(StandardCipherUnit):
