@@ -14,5 +14,5 @@ class HashUnit(Unit, abstract=True):
         super().__init__(text=text)
 
     def process(self, data: bytes) -> bytes:
-        digest = self._algorithm(data)
+        digest = self._algorithm(data).digest()
         return digest.hex().encode(self.codec) if self.args.text else digest
